# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.rules import delivery_method_pb2 as v1_dot_rules_dot_delivery__method__pb2


class DeliveryMethodServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.DeliveryMethodCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_method.DeliveryMethodService/DeliveryMethodCreate",
            request_serializer=v1_dot_rules_dot_delivery__method__pb2.DeliveryMethodCreateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__method__pb2.DeliveryMethodCreateResponse.FromString,
        )
        self.DeliveryMethodRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_method.DeliveryMethodService/DeliveryMethodRead",
            request_serializer=v1_dot_rules_dot_delivery__method__pb2.DeliveryMethodReadRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__method__pb2.DeliveryMethodReadResponse.FromString,
        )
        self.DeliveryMethodUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_method.DeliveryMethodService/DeliveryMethodUpdate",
            request_serializer=v1_dot_rules_dot_delivery__method__pb2.DeliveryMethodUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__method__pb2.DeliveryMethodUpdateResponse.FromString,
        )
        self.DeliveryMethodDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_method.DeliveryMethodService/DeliveryMethodDelete",
            request_serializer=v1_dot_rules_dot_delivery__method__pb2.DeliveryMethodDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__method__pb2.DeliveryMethodDeleteResponse.FromString,
        )


class DeliveryMethodServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def DeliveryMethodCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryMethodRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryMethodUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryMethodDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_DeliveryMethodServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "DeliveryMethodCreate": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryMethodCreate,
            request_deserializer=v1_dot_rules_dot_delivery__method__pb2.DeliveryMethodCreateRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__method__pb2.DeliveryMethodCreateResponse.SerializeToString,
        ),
        "DeliveryMethodRead": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryMethodRead,
            request_deserializer=v1_dot_rules_dot_delivery__method__pb2.DeliveryMethodReadRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__method__pb2.DeliveryMethodReadResponse.SerializeToString,
        ),
        "DeliveryMethodUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryMethodUpdate,
            request_deserializer=v1_dot_rules_dot_delivery__method__pb2.DeliveryMethodUpdateRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__method__pb2.DeliveryMethodUpdateResponse.SerializeToString,
        ),
        "DeliveryMethodDelete": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryMethodDelete,
            request_deserializer=v1_dot_rules_dot_delivery__method__pb2.DeliveryMethodDeleteRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__method__pb2.DeliveryMethodDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.rules.delivery_method.DeliveryMethodService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class DeliveryMethodService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def DeliveryMethodCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_method.DeliveryMethodService/DeliveryMethodCreate",
            v1_dot_rules_dot_delivery__method__pb2.DeliveryMethodCreateRequest.SerializeToString,
            v1_dot_rules_dot_delivery__method__pb2.DeliveryMethodCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryMethodRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_method.DeliveryMethodService/DeliveryMethodRead",
            v1_dot_rules_dot_delivery__method__pb2.DeliveryMethodReadRequest.SerializeToString,
            v1_dot_rules_dot_delivery__method__pb2.DeliveryMethodReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryMethodUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_method.DeliveryMethodService/DeliveryMethodUpdate",
            v1_dot_rules_dot_delivery__method__pb2.DeliveryMethodUpdateRequest.SerializeToString,
            v1_dot_rules_dot_delivery__method__pb2.DeliveryMethodUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryMethodDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_method.DeliveryMethodService/DeliveryMethodDelete",
            v1_dot_rules_dot_delivery__method__pb2.DeliveryMethodDeleteRequest.SerializeToString,
            v1_dot_rules_dot_delivery__method__pb2.DeliveryMethodDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )
